<?php

namespace Drupal\Tests\commerce_funds\Functional;

use Drupal\Tests\commerce\Functional\CommerceBrowserTestBase;

/**
 * Tests the deposit workflow.
 *
 * @group commerce_funds
 */
class DepositWorkflowTest extends CommerceBrowserTestBase {

  /**
   * Set default theme.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'commerce_funds',
    'commerce_exchanger',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() : void {
    parent::setUp();

    $this->firstUser = $this->drupalCreateUser([
      'deposit funds',
    ]);

    $this->paymentGateway = $this->createEntity('commerce_payment_gateway', [
      'id' => 'manual',
      'label' => 'Manual',
      'plugin' => 'manual',
      'collect_billing_information' => FALSE,
      'status' => 1,
    ]);

    $this->drupalLogin($this->firstUser);

    $this->transactionManager = \Drupal::service('commerce_funds.transaction_manager');
    $this->webAssert = $this->assertSession();
  }

  /**
   * Tests deposit workflow.
   */
  public function testDepositWorkflow() {
    // Go to the deposit form.
    $this->drupalGet('user/funds/deposit');
    $this->webAssert->statusCodeEquals(200);
    $this->submitForm([
      'amount' => 12.5,
      'currency' => 'USD',
    ], 'Next');

    $this->webAssert->addressEquals('checkout/1/order_information');

    // By default, manual method should be used
    // as it's the only one.
    $this->submitForm([
      'payment_information[billing_information][address][0][address][given_name]' => 'Anonymous',
      'payment_information[billing_information][address][0][address][family_name]' => 'Anonymous',
      'payment_information[billing_information][address][0][address][address_line1]' => 'Somewhere',
      'payment_information[billing_information][address][0][address][locality]' => 'City',
      'payment_information[billing_information][address][0][address][administrative_area]' => 'AL',
      'payment_information[billing_information][address][0][address][postal_code]' => '35242',
    ], 'Continue to review');

    $this->webAssert->addressEquals('checkout/1/review');

    $this->submitForm([], 'Pay and complete purchase');

    $this->webAssert->pageTextContains('12.50 USD have been added to your account balance');
    // Assert balance has been updated.
    $this->assertEquals(12.5, $this->transactionManager->loadAccountBalance($this->firstUser)['USD']);
  }

}
